@@ -131,14 +131,25 @@ class FeatureImplementationServicer:
 
         def wrapper(request: Message, context: ServicerContext) -> Message:
             metadata = extract_metadata(context, self.parent_server, cmd)
-            allowed_errors = _find_allowed_defined_execution_errors(self.parent_server, cmd, metadata.keys())
 
             params = unpack_parameters(cmd, request, context)
 
-            def _func_to_execute(
-                intermediate_response_queue: Queue[Any], execution_info_queue: Queue[CommandExecutionInfo]
-            ) -> Message:
-                with raises_rpc_errors(context, allowed_errors):
+            if cmd.intermediate_responses is None:
+
+                def _func_to_execute(execution_info_queue: Queue[CommandExecutionInfo]) -> Message:
+                    self.__apply_metadata_interceptors(None, metadata, cmd.fully_qualified_identifier)
+                    response = impl_func(
+                        *params,
+                        metadata=metadata,
+                        execution_info_queue=execution_info_queue,
+                    )
+                    return cmd.responses.to_message(response)
+
+            else:
+
+                def _func_to_execute(
+                    intermediate_response_queue: Queue[Any], execution_info_queue: Queue[CommandExecutionInfo]
+                ) -> Message:
                     self.__apply_metadata_interceptors(None, metadata, cmd.fully_qualified_identifier)
                     response = impl_func(
                         *params,
@@ -239,4 +250,5 @@ class FeatureImplementationServicer:
         self, parameters: Any, metadata: Dict[FullyQualifiedIdentifier, Any], target: FullyQualifiedIdentifier
     ):
         for interceptor in self.parent_server.metadata_interceptors:
-            interceptor.intercept(parameters, metadata, target)
+            if interceptor.required_metadata.issubset(metadata.keys()):
+                interceptor.intercept(parameters, metadata, target)
